# Do not check any files in docdir for Requires.
%global __requires_exclude_from ^%{_docdir}/.*$

%global gtest_ver 1.7.0


Name:		tapkee
Version:	1.1
Release:	2%{?dist}
Summary:	C++ template library for efficient dimension reduction

License:	BSD and BSD with advertising and LGPLv3+ and MIT
URL:		http://%{name}.lisitsyn.me/
Source0:	https://github.com/lisitsyn/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:	https://github.com/lisitsyn/%{name}_data/archive/master.tar.gz#/%{name}-data-%{version}.tar.gz
Source99:	https://github.com/google/googletest/archive/release-%{gtest_ver}.zip#/gtest-%{gtest_ver}.zip

BuildRequires:	arpack-devel
BuildRequires:	cmake
BuildRequires:	eigen3-devel
BuildRequires:	ocl-icd-devel

# copylib - Wildcard-exception granted by FPC.
# See: https://fedorahosted.org/fpc/ticket/174
Provides:	bundled(gnulib)

%description
Tapkee is a C++ template library for dimensionality reduction with
some bias on spectral methods.  The Tapkee origins from the code
developed during GSoC 2011 as the part of the Shogun machine learning
toolbox.  The project aim is to provide efficient and flexible
standalone library for dimensionality reduction which can be easily
integrated to existing codebases.  Tapkee leverages capabilities of
effective Eigen3 linear algebra library and optionally makes use of
the ARPACK eigensolver.  The library uses CoverTree and VP-tree
data-structures to compute nearest neighbors.  To achieve greater
flexibility we provide a callback interface which decouples dimension
reduction algorithms from the data representation and storage schemes.

Tapkee provides implementations of the following dimension reduction
methods:

  * Locally Linear Embedding and Kernel Locally Linear Embedding
    (LLE/KLLE)
  * Neighborhood Preserving Embedding (NPE)
  * Local Tangent Space Alignment (LTSA)
  * Linear Local Tangent Space Alignment (LLTSA)
  * Hessian Locally Linear Embedding (HLLE)
  * Laplacian eigenmaps
  * Locality Preserving Projections
  * Diffusion map
  * Isomap and landmark Isomap
  * Multidimensional scaling and landmark Multidimensional scaling
    (MDS/lMDS)
  * Stochastic Proximity Embedding (SPE)
  * PCA and randomized PCA
  * Kernel PCA (kPCA)
  * Random projection
  * Factor analysis
  * t-SNE
  * Barnes-Hut-SNE


%package cli
Summary:	CLI-tool for efficient dimension reduction

%description cli
Tapkee is a cli-tool for efficient dimension reduction and provides
implementations of the following dimension reduction methods:

  * Locally Linear Embedding and Kernel Locally Linear Embedding
    (LLE/KLLE)
  * Neighborhood Preserving Embedding (NPE)
  * Local Tangent Space Alignment (LTSA)
  * Linear Local Tangent Space Alignment (LLTSA)
  * Hessian Locally Linear Embedding (HLLE)
  * Laplacian eigenmaps
  * Locality Preserving Projections
  * Diffusion map
  * Isomap and landmark Isomap
  * Multidimensional scaling and landmark Multidimensional scaling
    (MDS/lMDS)
  * Stochastic Proximity Embedding (SPE)
  * PCA and randomized PCA
  * Kernel PCA (kPCA)
  * Random projection
  * Factor analysis
  * t-SNE
  * Barnes-Hut-SNE


%package devel
Summary:	C++ template library for efficient dimension reduction

Requires:	arpack-devel
Requires:	eigen3-devel

Obsoletes:	stichwort-devel		<= 1.0
Provides:	stichwort-devel		== %{version}-%{release}
Provides:	%{name}-static		== %{version}-%{release}

BuildArch:	noarch

%description devel
Tapkee is a C++ template library for dimensionality reduction with
some bias on spectral methods.  The Tapkee origins from the code
developed during GSoC 2011 as the part of the Shogun machine learning
toolbox.  The project aim is to provide efficient and flexible
standalone library for dimensionality reduction which can be easily
integrated to existing codebases.  Tapkee leverages capabilities of
effective Eigen3 linear algebra library and optionally makes use of
the ARPACK eigensolver.  The library uses CoverTree and VP-tree
data-structures to compute nearest neighbors.  To achieve greater
flexibility we provide a callback interface which decouples dimension
reduction algorithms from the data representation and storage schemes.

Tapkee provides implementations of the following dimension reduction
methods:

  * Locally Linear Embedding and Kernel Locally Linear Embedding
    (LLE/KLLE)
  * Neighborhood Preserving Embedding (NPE)
  * Local Tangent Space Alignment (LTSA)
  * Linear Local Tangent Space Alignment (LLTSA)
  * Hessian Locally Linear Embedding (HLLE)
  * Laplacian eigenmaps
  * Locality Preserving Projections
  * Diffusion map
  * Isomap and landmark Isomap
  * Multidimensional scaling and landmark Multidimensional scaling
    (MDS/lMDS)
  * Stochastic Proximity Embedding (SPE)
  * PCA and randomized PCA
  * Kernel PCA (kPCA)
  * Random projection
  * Factor analysis
  * t-SNE
  * Barnes-Hut-SNE


%package doc
Summary:	Documentation files for %{name}

BuildArch:	noarch

BuildRequires:	doxygen
BuildRequires:	fdupes
BuildRequires:	graphviz

%description doc
This package contains the documentation files and some brief examples
for %{name}.


%prep
%autosetup -p 1

# Setup data for examples.
%autosetup -DTa 1
%{__rm} -fr data/
%{__mv} -f %{name}_data-master examples/data

# Setup gtest for testsuite.
%autosetup -DTa 99
%{__mv} -f googletest-release-%{gtest_ver} gtest-%{gtest_ver}


%build
%{__mkdir} -p %{_target_platform}
pushd %{_target_platform}
%cmake				\
	-DBUILD_TESTS=ON	\
	-DPRECOMPUTED=ON	\
	-DUSE_GCOV=ON		\
	..
%make_build
popd

# Build autodocs.
%{_bindir}/doxygen doc/Doxyfile
%fdupes doc


%install
# Install the includes.
%{__mkdir} -p %{buildroot}%{_includedir}
%{__cp} -pr include/* %{buildroot}%{_includedir}

# Install the cli-tool.
%{__install} -Dpm 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# Remove build-system files from examples.
%{_bindir}/find examples -depth -type f -name 'CMakeLists.txt' -print -delete


%check
pushd %{_target_platform}
%{_bindir}/ctest --output-on-failure -vv || :
popd


%files cli
%doc README*
%license AUTHORS
%license *LICENSE*
%{_bindir}/%{name}


%files devel
%doc README*
%license AUTHORS
%license *LICENSE*
%{_includedir}/*


%files doc
%doc README*
%doc doc/html
%doc doc/methods
%doc examples
%license AUTHORS
%license *LICENSE*


%changelog
* Sat Apr 29 2017 Björn Esser <besser82@fedoraproject.org> - 1.1-2
- Add Obsoletes/Provides for stichwort

* Sat Apr 29 2017 Björn Esser <besser82@fedoraproject.org> - 1.1-1
- New upstream release
- General spec-file clean-up

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Dec 22 2016 Sandro Mani <manisandro@gmail.com> - 1.0-7
- Backport upstream commit to fix Eigen-3.3.0 build failure

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.0-4
- Rebuilt for GCC 5 C++11 ABI change

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Sep 20 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0-1
- Initial rpm release (#1010565)
